rlist-package: The rlist package
Description
The rlist packageDetails
rlist is a set of tools for working with list objects. Its goal
is to make it easier to work with lists by providing a wide range
of functions that operate on non-tabular data stored in them.
The package provides a set of functions for data manipulation with
list objects, including mapping, filtering, grouping, sorting,
updating, searching, and other useful functions. Most functions
are designed to be pipeline friendly so that data processing with
lists can be chained.
rlist Tutorial (http://renkun.me/rlist-tutorial) is a complete guide to rlist.